==> nextcloud-13.0.1.tgz: nextcloud/apps/systemtags/l10n/sq.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Etiketa",
    "Update" : "Përditëso",
    "Create" : "Krijo",
    "Select tag…" : "Përzgjidh etiketën...",
    "Tagged files" : "Kartela të etiketuara",
    "Select tags to filter by" : "Përzgjidhni etiketa sipas të cilat të bëhet filtrimi",
    "No tags found" : "Asnjë etiket nuk u gjet",
    "Please select tags to filter by" : "Ju lutemi, përzgjidhni etiketa sipas të cilat të bëhet filtrimi",
    "No files found for the selected tags" : "S’u gjetën kartela për etiketat e përzgjedhura",
    "Added system tag %1$s" : "U shtua etiketa %1$s e sistemit ",
    "Added system tag {systemtag}" : "Tagu i shtuar i sistemit{systemtag}",
    "%1$s added system tag %2$s" : "%1$s shtoi etiketën %2$s të sistemit ",
    "{actor} added system tag {systemtag}" : "{actor} shtoi etiketën e sistemit {systemtag}",
    "Removed system tag %1$s" : "Hoqi  etiketën %1$s të sistemit ",
    "Removed system tag {systemtag}" : "Hoqi etiketën e sistemit {systemtag}",
    "%1$s removed system tag %2$s" : "%1$s hoqi etiketën %2$s të sistemit ",
    "{actor} removed system tag {systemtag}" : "{actor} hoqi etiketën e sistemit {systemtag}",
    "You created system tag %1$s" : "Ju krijuat etiketën %1$s të sistemit",
    "You created system tag {systemtag}" : "Ju keni krijuar etiketimin e sistemit {systemtag}",
    "%1$s created system tag %2$s" : "%1$s krijoi etiketën e sistemit %2$s",
    "{actor} created system tag {systemtag}" : "{actor} krijoi etiketimin e sistemit {systemtag}",
    "You deleted system tag %1$s" : "Ju fshit etiketën %1$s të sistemit",
    "You deleted system tag {systemtag}" : "Ju fshit etiketën {systemtag} të sistemit",
    "%1$s deleted system tag %2$s" : "%1$s fshiu etiketën e sistemit %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} fshiu etiketën {systemtag} të sistemit",
    "You updated system tag %2$s to %1$s" : "Ju përditësuat etiketën e sistemit nga %2$s në %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Ju përditësuat etiketën e sistemit nga {oldsystemtag} në {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s përditësoi etiketën e sistemit %3$s si %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} përditësoi etiketimin e sistemit {oldsystemtag} në {newsystemtag}",
    "You added system tag %2$s to %1$s" : "Ju shtuat tagun e sistemit%2$s në %1$s",
    "You added system tag {systemtag} to {file}" : "Ju shtuat tagun e sistemit{systemtag} në{file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s shtoi etiketën e sistemit %3$s në %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} shtoi etiketimin e sistemit {systemtag} në {file}",
    "You removed system tag %2$s from %1$s" : "Ju hoqët etiketimin e sistemit %2$s nga %1$s",
    "You removed system tag {systemtag} from {file}" : "Hoqët etiketën e sistemit {systemtag} nga {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s hoqi etiketimin e sistemit %3$s nga %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} hoqi etiketimin e sistemit {systemtag} nga {file}",
    "%s (restricted)" : "%s (e kufizuar)",
    "%s (invisible)" : "%s (e padukshme)",
    "<strong>System tags</strong> for a file have been modified" : "U ndryshyan <strong>etiketa sistemi</strong>për një kartelë",
    "Collaborative tags" : "Etiketa bashkëpunuese",
    "Create and edit collaborative tags. These tags affect all users." : "Krijo dhe ndrysho etiketa bashkëpunuese. Këto etiketa ndikojnë tek të gjithë përdoruesit.",
    "Select tag …" : "Zgjidh etiketimin",
    "Name" : "Emër",
    "Delete" : "Fshije",
    "Public" : "Publik",
    "Restricted" : "I/E kufizuar",
    "Invisible" : "I padukshëm",
    "Reset" : "Rivendos",
    "No files in here" : "S’ka kartela këtu",
    "No entries found in this folder" : "S’u gjetën zëra në këtë dosje",
    "Size" : "Madhësi",
    "Modified" : "Ndryshuar më"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.5p1.tgz: nextcloud/apps/systemtags/l10n/sq.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Etiketa",
    "Update" : "Përditëso",
    "Create" : "Krijo",
    "Select tag…" : "Përzgjidh etiketën...",
    "Added system tag {systemtag}" : "Tagu i shtuar i sistemit{systemtag}",
    "Added system tag %1$s" : "U shtua etiketa %1$s e sistemit ",
    "%1$s added system tag %2$s" : "%1$s shtoi etiketën %2$s të sistemit ",
    "{actor} added system tag {systemtag}" : "{actor} shtoi etiketën e sistemit {systemtag}",
    "Removed system tag {systemtag}" : "Hoqi etiketën e sistemit {systemtag}",
    "Removed system tag %1$s" : "Hoqi  etiketën %1$s të sistemit ",
    "%1$s removed system tag %2$s" : "%1$s hoqi etiketën %2$s të sistemit ",
    "{actor} removed system tag {systemtag}" : "{actor} hoqi etiketën e sistemit {systemtag}",
    "You created system tag %1$s" : "Ju krijuat etiketën %1$s të sistemit",
    "You created system tag {systemtag}" : "Ju keni krijuar etiketimin e sistemit {systemtag}",
    "%1$s created system tag %2$s" : "%1$s krijoi etiketën e sistemit %2$s",
    "{actor} created system tag {systemtag}" : "{actor} krijoi etiketimin e sistemit {systemtag}",
    "You deleted system tag %1$s" : "Ju fshit etiketën %1$s të sistemit",
    "You deleted system tag {systemtag}" : "Ju fshit etiketën {systemtag} të sistemit",
    "%1$s deleted system tag %2$s" : "%1$s fshiu etiketën e sistemit %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} fshiu etiketën {systemtag} të sistemit",
    "You updated system tag %2$s to %1$s" : "Ju përditësuat etiketën e sistemit nga %2$s në %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Ju përditësuat etiketën e sistemit nga {oldsystemtag} në {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s përditësoi etiketën e sistemit %3$s si %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} përditësoi etiketimin e sistemit {oldsystemtag} në {newsystemtag}",
    "You added system tag %2$s to %1$s" : "Ju shtuat tagun e sistemit%2$s në %1$s",
    "You added system tag {systemtag} to {file}" : "Ju shtuat tagun e sistemit{systemtag} në{file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s shtoi etiketën e sistemit %3$s në %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} shtoi etiketimin e sistemit {systemtag} në {file}",
    "You removed system tag %2$s from %1$s" : "Ju hoqët etiketimin e sistemit %2$s nga %1$s",
    "You removed system tag {systemtag} from {file}" : "Hoqët etiketën e sistemit {systemtag} nga {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s hoqi etiketimin e sistemit %3$s nga %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} hoqi etiketimin e sistemit {systemtag} nga {file}",
    "%s (restricted)" : "%s (e kufizuar)",
    "%s (invisible)" : "%s (e padukshme)",
    "<strong>System tags</strong> for a file have been modified" : "U ndryshyan <strong>etiketa sistemi</strong>për një kartelë",
    "Collaborative tags" : "Etiketa bashkëpunuese",
    "Tagged files" : "Kartela të etiketuara",
    "Select tags to filter by" : "Përzgjidhni etiketa sipas të cilat të bëhet filtrimi",
    "No tags found" : "Asnjë etiket nuk u gjet",
    "Please select tags to filter by" : "Ju lutemi, përzgjidhni etiketa sipas të cilat të bëhet filtrimi",
    "No files found for the selected tags" : "S’u gjetën kartela për etiketat e përzgjedhura",
    "Select tag …" : "Zgjidh etiketimin",
    "Name" : "Emër",
    "Public" : "Publik",
    "Restricted" : "I/E kufizuar",
    "Invisible" : "I padukshëm",
    "Delete" : "Fshije",
    "Reset" : "Rivendos",
    "No files in here" : "S’ka kartela këtu",
    "No entries found in this folder" : "S’u gjetën zëra në këtë dosje",
    "Size" : "Madhësi",
    "Modified" : "Ndryshuar më",
    "Create and edit collaborative tags. These tags affect all users." : "Krijo dhe ndrysho etiketa bashkëpunuese. Këto etiketa ndikojnë tek të gjithë përdoruesit."
},
"nplurals=2; plural=(n != 1);");
